==> phpnuke-5.5.tgz: www/phpnuke/html/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","windows-1250");
define("_SEARCH","Hledat");
define("_LOGIN","Pihlen");
define("_WRITES","pe");
define("_POSTEDON","Posted on");
define("_NICKNAME","Pezdvka");
define("_PASSWORD","Heslo");
define("_WELCOMETO","Vtejte na");
define("_EDIT","Upravit");
define("_DELETE","Smazat");
define("_POSTEDBY","Poslal");
define("_READS","ten");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Zpt</a> ]");
define("_COMMENTS","komente");
define("_PASTARTICLES","Minul lnky");
define("_OLDERARTICLES","Star lnky");
define("_BY","podle");
define("_ON","v");
define("_LOGOUT","Odhlsit");
define("_WAITINGCONT","A tohle ek");
define("_SUBMISSIONS","Pspvky");
define("_WREVIEWS","Recenze");
define("_WLINKS","Odkazy");
define("_EPHEMERIDS","Udlosti");
define("_ONEDAY","Den jako kad jin...");
define("_ASREGISTERED","Jet nemte svj et? Mete si jej <a href=\"modules.php?name=Your_Account\">vytvoit zde</a>. Jako registrovan uivatel zskte adu vhod. Napklad posln komentu pod jmnem, nastaven koment, manaer tmat atd.");
define("_MENUFOR","Menu pro");
define("_NOBIGSTORY","Dosud nen lnek dne.");
define("_BIGSTORY","Nejtenj lnek dnes je:");
define("_SURVEY","Anketa");
define("_POLLS","Ankety");
define("_PCOMMENTS","Koment");
define("_RESULTS","Vsledky");
define("_HREADMORE","vce...");
define("_CURRENTLY","Prv je");
define("_GUESTS","nvtvnk() a");
define("_MEMBERS","uivatel() online.");
define("_YOUARELOGGED","Jste pihlen jako");
define("_YOUHAVE","Mte");
define("_PRIVATEMSG","osobnch zprv.");
define("_YOUAREANON","Jste anonymn uivatel. Mete se zdarma registrovat kliknutm <a href=\"modules.php?name=Your_Account\">zde</a>");
define("_NOTE","Poznmka:");
define("_ADMIN","Admin:");
define("_WERECEIVED","Zaznamenali jsme");
define("_PAGESVIEWS","pstup od");
define("_TOPIC","Tma");
define("_UDOWNLOADS","Staen");
define("_VOTE","Hlasovat");
define("_VOTES","Hlas");
define("_MVIEWADMIN","Zobrazit: Pouze administrtorm");
define("_MVIEWUSERS","Zobrazit: Pouze pihlenm uivatelm");
define("_MVIEWANON","Zobrazit: Pouze anonymm");
define("_MVIEWALL","Zobrazit: Vem nvtvnkm");
define("_EXPIRELESSHOUR","Konec zobrazovn: mn ne 1 hodina");
define("_EXPIREIN","Konec zobrazovn za");
define("_HTTPREFERERS","Odkud pili");
define("_UNLIMITED","Neomezeno");
define("_HOURS","hodin(a/y)");
define("_RSSPROBLEM","Momentln je problm se zprvami z tohoto webu");
define("_SELECTLANGUAGE","Vyberte si jazyk");
define("_SELECTGUILANG","Vyberte si jazykov rozhran:");
define("_NONE","Nen");
define("_BLOCKPROBLEM","<center>There is a problem right now with this block.</center>");
define("_BLOCKPROBLEM2","<center>There isn't content right now for this block.</center>");
define("_MODULENOTACTIVE","Sorry, this Module isn't active!");
define("_NOACTIVEMODULES","Inactive Modules");
define("_FORADMINTESTS","(for Admin tests)");
define("_BBFORUMS","Forums");
define("_ACCESSDENIED", "Access Denied");
define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
define("_ADDAHOME","Add a Module in your Home");
define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
define("_MORENEWS","More in News Section");
define("_ALLCATEGORIES","All Categories");
define("_DATESTRING","%A, %d. %B %Y @ %T %Z");
define("_DATESTRING2","%A, %d. %B");
define("_DATE","Date");
define("_HOUR","Hour");
define("_UMONTH","Month");
define("_YEAR","Year");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","windows-1250");
define("_SEARCH","Hledat");
define("_LOGIN","Pihlen");
define("_WRITES","pe");
define("_POSTEDON","Posted on");
define("_NICKNAME","Pezdvka");
define("_PASSWORD","Heslo");
define("_WELCOMETO","Vtejte na");
define("_EDIT","Upravit");
define("_DELETE","Smazat");
define("_POSTEDBY","Poslal");
define("_READS","ten");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Zpt</a> ]");
define("_COMMENTS","komente");
define("_PASTARTICLES","Minul lnky");
define("_OLDERARTICLES","Star lnky");
define("_BY","podle");
define("_ON","v");
define("_LOGOUT","Odhlsit");
define("_WAITINGCONT","A tohle ek");
define("_SUBMISSIONS","Pspvky");
define("_WREVIEWS","Recenze");
define("_WLINKS","Odkazy");
define("_EPHEMERIDS","Udlosti");
define("_ONEDAY","Den jako kad jin...");
define("_ASREGISTERED","Jet nemte svj et? Mete si jej <a href=\"modules.php?name=Your_Account\">vytvoit zde</a>. Jako registrovan uivatel zskte adu vhod. Napklad posln komentu pod jmnem, nastaven koment, manaer tmat atd.");
define("_MENUFOR","Menu pro");
define("_NOBIGSTORY","Dosud nen lnek dne.");
define("_BIGSTORY","Nejtenj lnek dnes je:");
define("_SURVEY","Anketa");
define("_POLLS","Ankety");
define("_PCOMMENTS","Koment");
define("_RESULTS","Vsledky");
define("_HREADMORE","vce...");
define("_CURRENTLY","Prv je");
define("_GUESTS","nvtvnk() a");
define("_MEMBERS","uivatel() online.");
define("_YOUARELOGGED","Jste pihlen jako");
define("_YOUHAVE","Mte");
define("_PRIVATEMSG","osobnch zprv.");
define("_YOUAREANON","Jste anonymn uivatel. Mete se zdarma registrovat kliknutm <a href=\"modules.php?name=Your_Account\">zde</a>");
define("_NOTE","Poznmka:");
define("_ADMIN","Admin:");
define("_WERECEIVED","Zaznamenali jsme");
define("_PAGESVIEWS","pstup od");
define("_TOPIC","Tma");
define("_UDOWNLOADS","Staen");
define("_VOTE","Hlasovat");
define("_VOTES","Hlas");
define("_MVIEWADMIN","Zobrazit: Pouze administrtorm");
define("_MVIEWUSERS","Zobrazit: Pouze pihlenm uivatelm");
define("_MVIEWANON","Zobrazit: Pouze anonymm");
define("_MVIEWALL","Zobrazit: Vem nvtvnkm");
define("_EXPIRELESSHOUR","Konec zobrazovn: mn ne 1 hodina");
define("_EXPIREIN","Konec zobrazovn za");
define("_HTTPREFERERS","Odkud pili");
define("_UNLIMITED","Neomezeno");
define("_HOURS","hodin(a/y)");
define("_RSSPROBLEM","Momentln je problm se zprvami z tohoto webu");
define("_SELECTLANGUAGE","Vyberte si jazyk");
define("_SELECTGUILANG","Vyberte si jazykov rozhran:");
define("_NONE","Nen");
define("_BLOCKPROBLEM","<center>There is a problem right now with this block.</center>");
define("_BLOCKPROBLEM2","<center>There isn't content right now for this block.</center>");
define("_MODULENOTACTIVE","Sorry, this Module isn't active!");
define("_NOACTIVEMODULES","Inactive Modules");
define("_FORADMINTESTS","(for Admin tests)");
define("_BBFORUMS","Forums");
define("_ACCESSDENIED", "Access Denied");
define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
define("_ADDAHOME","Add a Module in your Home");
define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
define("_MORENEWS","More in News Section");
define("_ALLCATEGORIES","All Categories");
define("_DATESTRING","%A, %d. %B %Y @ %T %Z");
define("_DATESTRING2","%A, %d. %B");
define("_DATE","Date");
define("_HOUR","Hour");
define("_UMONTH","Month");
define("_YEAR","Year");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>
